@@ -23,6 +23,8 @@
 #include <injeqt/injeqt.h>
 #include <injeqt/type.h>
 
+#include "internal.h"
+
 #include "sorted-unique-vector.h"
 
 namespace injeqt { namespace internal {
@@ -34,6 +36,6 @@ inline std::string name_from_type(const type &t)
 
 using types_by_name = sorted_unique_vector<std::string, type, name_from_type>;
 
-type type_by_pointer(const types_by_name &known_types, const std::string &pointer_name);
+INJEQT_INTERNAL_API type type_by_pointer(const types_by_name &known_types, const std::string &pointer_name);
 
 }}
